StrokeOptions class

Constructors

StrokeOptions({double? size, double? thinning, double? smoothing, double? streamline, NumericEasing? easing, bool? simulatePressure, TaperOptions? start, TaperOptions? end, bool? last})

Properties

easing ↔ NumericEasing
getter/setter pair
end ↔ TaperOptions
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
last ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simulatePressure ↔ bool
getter/setter pair
size ↔ double
getter/setter pair
smoothing ↔ double
getter/setter pair
start ↔ TaperOptions
getter/setter pair
streamline ↔ double
getter/setter pair
thinning ↔ double
getter/setter pair

Methods

copyWith({double? size, double? thinning, double? smoothing, double? streamline, NumericEasing? easing, bool? simulatePressure, TaperOptions? start, TaperOptions? end, bool? last}) → StrokeOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultEasing ↔ NumericEasing
getter/setter pair
defaultEnd ↔ TaperOptions
getter/setter pair
defaultLast ↔ bool
getter/setter pair
defaultSimulatePressure ↔ bool
getter/setter pair
defaultSize ↔ double
getter/setter pair
defaultSmoothing ↔ double
getter/setter pair
defaultStart ↔ TaperOptions
getter/setter pair
defaultStreamline ↔ double
getter/setter pair
defaultThinning ↔ double
getter/setter pair